@@ -5,8 +5,8 @@
 #include "rc.h"
 
 extern rcvar_t rcfile_exports[], emu_exports[], loader_exports[],
-	lcd_exports[], debug_exports[], vid_exports[],
-	sound_exports[], pcm_exports[];
+	lcd_exports[], rtc_exports[], debug_exports[], sound_exports[],
+	vid_exports[], joy_exports[], pcm_exports[];
 
 
 rcvar_t *sources[] =
@@ -15,9 +15,11 @@ rcvar_t *sources[] =
 	emu_exports,
 	loader_exports,
 	lcd_exports,
+	rtc_exports,
 	debug_exports,
-	vid_exports,
 	sound_exports,
+	vid_exports,
+	joy_exports,
 	pcm_exports,
 	NULL
 };
