@@ -13,6 +13,8 @@
 #define MBC_MBC3 3
 #define MBC_MBC5 5
 #define MBC_RUMBLE 15
+#define MBC_HUC1 0xC1
+#define MBC_HUC3 0xC3
 
 struct mbc
 {
@@ -27,23 +29,21 @@ struct mbc
 	byte *rmap[0x10], *wmap[0x10];
 };
 
-
 struct rom
 {
 	byte (*bank)[16384];
+	char name[20];
 };
 
 struct ram
 {
+	byte hi[256];
 	byte ibank[8][4096];
 	byte (*sbank)[8192];
-	byte stack[128];
 	int loaded;
 };
 
 
-
-
 extern struct mbc mbc;
 extern struct rom rom;
 extern struct ram ram;
@@ -59,7 +59,6 @@ void mem_write(int a, byte b);
 byte mem_read(int a);
 
 
-extern int forcedmg;
 
 #define READB(a) ( mbc.rmap[(a)>>12] \
 ? mbc.rmap[(a)>>12][(a)] \
@@ -71,9 +70,6 @@ extern int forcedmg;
 : ( mem_write((a), (b)), (b) ) )
 #define WRITEW(a, w) ( WRITEB((a), (w)&0xFF), WRITEB((a)+1, (w)>>8) )
 
-#define CGB_ROM (!forcedmg && rom.bank && (rom.bank[0][0x0143] == 0x80 \
-|| rom.bank[0][0x0143] == 0xC0))
-
 
 
 
