@@ -7,23 +7,20 @@
 struct sndchan
 {
 	int on;
-	int pos, freq, pat;
-	int len, cnt;
-	int envol, endir, enlen, encnt;
-};
-
-struct sweep
-{
-	int len, cnt, dir, shift;
+	unsigned pos;
+	int cnt, encnt, swcnt;
+	int len, enlen, swlen;
+	int swfreq;
+	int freq;
+	int envol, endir;
 };
 
 
 struct snd
 {
-	byte wave[16];
 	int rate;
 	struct sndchan ch[4];
-	struct sweep sw;
+	byte wave[16];
 };
 
 
