@@ -9,7 +9,7 @@
 
 struct pcm pcm;
 
-static buf[4096];
+static byte buf[4096];
 
 
 rcvar_t pcm_exports[] =
@@ -26,8 +26,9 @@ void pcm_init()
 	pcm.pos = 0;
 }
 
-void pcm_shutdown()
+void pcm_close()
 {
+	memset(&pcm, 0, sizeof pcm);
 }
 
 int pcm_submit()
